==> thx_fcm-0.0.4.tar.gz: thx_fcm-0.0.4/thx/fcm/models.py <==
# -*- coding: utf-8 -*-

"""
Device
============

È stata creata la classe Device estendendo la classe AbstractFCMDevice (di fcm-django) 
per ridefinirne alcuni attributi e per aggiungere funzionalità

* :class:`Device` (``AbstractFCMDevice``, ``CleanModel``, ``DateModel``, ``OrderedModel``)


Modelli
========

.. autoclass:: Device
   :members:

"""
from __future__ import unicode_literals

from django.conf import settings
from django.core.exceptions import ValidationError
from django.db import models
from django.utils import timezone
from django.utils.translation import ugettext_lazy as _

from fcm_django.models import AbstractFCMDevice
from firebase_admin import messaging

from thx.core.models import CleanModel, DateModel, OrderedModel


class Device(AbstractFCMDevice, CleanModel, DateModel, OrderedModel):
    version = models.CharField(
        verbose_name=_("version"),
        max_length=150
    )
    manufacturer = models.CharField(
        verbose_name=_("manufacturer"),
        max_length=150
    )
    reference = models.CharField(
        blank=True, null=True,
        max_length=150,
        verbose_name=_('reference'),
    )

    class Meta:
        verbose_name = _('device')
        verbose_name_plural = _('devices')
        ordering = ('ordering', '-date_last_modify')
        constraints = [
            models.UniqueConstraint(fields=['device_id', 'registration_id'], name='unique device')
        ]
        permissions = (
            ("list_device", "Can list device"),
            ("detail_device", "Can detail device"),
            ("disable_device", "Can disable device"),
        )

    def __str__(self):
        return '{}: {}'.format(
            self.reference,
            self.device_id
        )

    def clean(self):
        self.check_registration_id_is_valid()
        super().clean()

    @classmethod
    def get_android_notification(
            cls, priority='high', sound='default', channel_id=None, color="#ff0000", icon=None, notification_count=None
    ):
        return messaging.AndroidNotification(
            priority=priority,
            sound=sound,
            channel_id=channel_id,
            color=color,
            icon=icon,
            notification_count=notification_count
        )

    @classmethod
    def get_android_config(cls, android_notification, priority='high', collapse_key=None):
        return messaging.AndroidConfig(
            priority=priority,
            collapse_key=collapse_key,
            notification=android_notification
        )

    @classmethod
    def get_aps(cls, badge=None, sound="default"):
        return messaging.Aps(badge=badge, sound=sound)

    @classmethod
    def get_apns_payload(cls, aps):
        return messaging.APNSPayload(aps=aps)

    @classmethod
    def get_apns_config(cls, apns_payload):
        return messaging.APNSConfig(payload=apns_payload)

    @classmethod
    def get_webpush_config(cls, fcm_options):
        return messaging.WebpushConfig(
            fcm_options=fcm_options
        )

    @classmethod
    def get_webpush_fcm_options(cls, link):
        return messaging.WebpushFCMOptions(
            link=link
        )

    @classmethod
    def get_notification(cls, title, body, image=None):
        return messaging.Notification(
            title=title,
            body=body,
            image=image,
        )

    @classmethod
    def get_message(cls, notification, data=None, android=None, apns=None, webpush=None):
        return messaging.Message(
            notification=notification,
            data=data,
            android=android,
            apns=apns,
            webpush=webpush
        )

    @classmethod
    def send_test_fcm_message(cls, devices=None):
        android = cls.get_test_android()
        apns = cls.get_test_apns()
        webpush = cls.get_test_webpush()
        notification = cls.get_test_notification()
        data = cls.get_test_data()
        message = cls.get_message(
            notification=notification,
            android=android,
            apns=apns,
            webpush=webpush,
            data=data
        )

        if not devices:
            devices = cls.objects.filter(active=True)
        devices.send_message(message)

    @classmethod
    def get_test_android(cls):
        android_notification = cls.get_android_notification(
            sound='default',
            color="#ff0000",
        )
        android_config = cls.get_android_config(
            android_notification=android_notification,
            priority='high',
            collapse_key='test',
        )
        return android_config

    @classmethod
    def get_test_apns(cls):
        aps = cls.get_aps(sound='default')
        apns_payload = cls.get_apns_payload(aps=aps)
        apns_config = cls.get_apns_config(apns_payload=apns_payload)
        return apns_config

    @classmethod
    def get_test_webpush(cls):
        fcm_options = cls.get_webpush_fcm_options(link='https://adrenalinik.quasar.thux.dev')
        webpush = cls.get_webpush_config(fcm_options=fcm_options)
        return webpush

    @classmethod
    def get_test_notification(cls):
        title = "Title: Test FCM send"
        body = f"Body: Test FCM send {timezone.now()}"
        return cls.get_notification(title=title, body=body)

    @classmethod
    def get_test_data(cls):
        return {
            "title": f"Test FCM send {timezone.now()}",
            "body": "Test FCM send <strong> YES! </strong> test length test length test length test length.",
        }

    def check_registration_id_is_valid(self):
        notification = Device.get_test_notification()
        message = Device.get_message(
            notification=notification,
        )
        response = self.send_message(message, dry_run=True)

        success = getattr(response, 'success', None)
        if success:
            return True

        http_response = getattr(response, 'http_response', None)
        if http_response is not None and http_response.status_code != 200:
            json = http_response.json()
            message = json.get('error', {}).get('message')
            raise ValidationError({'registration_id': message})

        raise ValidationError({'registration_id': _('Invalid FCM registration Process')})

==> thx_fcm-0.0.5.tar.gz: thx_fcm-0.0.5/thx/fcm/models.py <==
# -*- coding: utf-8 -*-

"""
Device
============

È stata creata la classe Device estendendo la classe AbstractFCMDevice (di fcm-django) 
per ridefinirne alcuni attributi e per aggiungere funzionalità

* :class:`Device` (``AbstractFCMDevice``, ``CleanModel``, ``DateModel``, ``OrderedModel``)


Modelli
========

.. autoclass:: Device
   :members:

"""
from __future__ import unicode_literals

from django.core.exceptions import ValidationError
from django.db import models
from django.utils import timezone
from django.utils.translation import gettext_lazy as _

from fcm_django.models import AbstractFCMDevice
from firebase_admin import messaging

from thx.core.models import CleanModel, DateModel, OrderedModel


class Device(AbstractFCMDevice, CleanModel, DateModel, OrderedModel):
    version = models.CharField(
        verbose_name=_("version"),
        max_length=150
    )
    manufacturer = models.CharField(
        verbose_name=_("manufacturer"),
        max_length=150
    )
    reference = models.CharField(
        blank=True, null=True,
        max_length=150,
        verbose_name=_('reference'),
    )

    class Meta:
        verbose_name = _('device')
        verbose_name_plural = _('devices')
        ordering = ('ordering', '-date_last_modify')
        constraints = [
            models.UniqueConstraint(fields=['device_id', 'registration_id'], name='unique device')
        ]
        permissions = (
            ("list_device", "Can list device"),
            ("detail_device", "Can detail device"),
            ("disable_device", "Can disable device"),
        )

    def __str__(self):
        return '{}: {}'.format(
            self.reference,
            self.device_id
        )

    def clean(self):
        self.check_registration_id_is_valid()
        super().clean()

    @classmethod
    def get_android_notification(
            cls, priority='high', sound='default', channel_id=None, color="#ff0000", icon=None, notification_count=None
    ):
        return messaging.AndroidNotification(
            priority=priority,
            sound=sound,
            channel_id=channel_id,
            color=color,
            icon=icon,
            notification_count=notification_count
        )

    @classmethod
    def get_android_config(cls, android_notification, priority='high', collapse_key=None):
        return messaging.AndroidConfig(
            priority=priority,
            collapse_key=collapse_key,
            notification=android_notification
        )

    @classmethod
    def get_aps(cls, badge=None, sound="default"):
        return messaging.Aps(badge=badge, sound=sound)

    @classmethod
    def get_apns_payload(cls, aps):
        return messaging.APNSPayload(aps=aps)

    @classmethod
    def get_apns_config(cls, apns_payload):
        return messaging.APNSConfig(payload=apns_payload)

    @classmethod
    def get_webpush_config(cls, fcm_options):
        return messaging.WebpushConfig(
            fcm_options=fcm_options
        )

    @classmethod
    def get_webpush_fcm_options(cls, link):
        return messaging.WebpushFCMOptions(
            link=link
        )

    @classmethod
    def get_notification(cls, title, body, image=None):
        return messaging.Notification(
            title=title,
            body=body,
            image=image,
        )

    @classmethod
    def get_message(cls, notification, data=None, android=None, apns=None, webpush=None):
        return messaging.Message(
            notification=notification,
            data=data,
            android=android,
            apns=apns,
            webpush=webpush
        )

    @classmethod
    def send_test_fcm_message(cls, devices=None):
        android = cls.get_test_android()
        apns = cls.get_test_apns()
        webpush = cls.get_test_webpush()
        notification = cls.get_test_notification()
        data = cls.get_test_data()
        message = cls.get_message(
            notification=notification,
            android=android,
            apns=apns,
            webpush=webpush,
            data=data
        )

        if not devices:
            devices = cls.objects.filter(active=True)
        devices.send_message(message)

    @classmethod
    def get_test_android(cls):
        android_notification = cls.get_android_notification(
            sound='default',
            color="#ff0000",
        )
        android_config = cls.get_android_config(
            android_notification=android_notification,
            priority='high',
            collapse_key='test',
        )
        return android_config

    @classmethod
    def get_test_apns(cls):
        aps = cls.get_aps(sound='default')
        apns_payload = cls.get_apns_payload(aps=aps)
        apns_config = cls.get_apns_config(apns_payload=apns_payload)
        return apns_config

    @classmethod
    def get_test_webpush(cls):
        fcm_options = cls.get_webpush_fcm_options(link='https://adrenalinik.quasar.thux.dev')
        webpush = cls.get_webpush_config(fcm_options=fcm_options)
        return webpush

    @classmethod
    def get_test_notification(cls):
        title = "Title: Test FCM send"
        body = f"Body: Test FCM send {timezone.now()}"
        return cls.get_notification(title=title, body=body)

    @classmethod
    def get_test_data(cls):
        return {
            "title": f"Test FCM send {timezone.now()}",
            "body": "Test FCM send <strong> YES! </strong> test length test length test length test length.",
        }

    def check_registration_id_is_valid(self):
        notification = Device.get_test_notification()
        message = Device.get_message(
            notification=notification,
        )
        response = self.send_message(message, dry_run=True)

        success = getattr(response, 'success', None)
        if success:
            return True

        http_response = getattr(response, 'http_response', None)
        if http_response is not None and http_response.status_code != 200:
            json = http_response.json()
            message = json.get('error', {}).get('message')
            raise ValidationError({'registration_id': message})

        raise ValidationError({'registration_id': _('Invalid FCM registration Process')})
